==> SSOAP_0.2-2.tar.gz: SSOAP/man/processWSDL.Rd <==
\name{processWSDL}
\alias{processWSDL}
\title{Read and process a Web Service Description Language file}
\description{
  This reads and converts a WSDL file for a server
  into a collection of functions and methods.
}
\usage{
processWSDL(fileName = "KEGG.wsdl")
}
\arguments{
  \item{fileName}{the name of the WSDL file or URI.}
}
\details{

}
\value{
   An object of class \code{\link{SOAPServerDescription}}.
}

\author{Duncan Temple Lang <duncan@wald.ucdavis.edu>}
\seealso{
  \code{UseDashInSOAPNames} is an R option that can be set by the
  user that is understood by this package to control
  whether to either leave SOAP method names as-is,
  or if \code{FALSE}, to remove \code{_} in the
  names and capitalize the first character in all but
  the first word of the name. In other words, if
  \code{UseDashInSOAPNames} is set to FALSE,
  the name \code{abc_def_ghi} is mapped to
  \code{abcDefGhi}.  By default,
  the value is unset and
  treated as \code{TRUE}, so dashes are preserved.
}

\examples{
  tmp = processWSDL(system.file("examples", "KEGG.wsdl", package = "SSOAP"))

   # The first set of operations, and the method "color_pathway_by_objects"
  o = tmp@operations[[1]][["color_pathway_by_objects"]]
  names(o@parameters)
  o@parameters[["fg_color_list"]]
  o@returnValue


  ff = genSOAPClientInterface(tmp@operations[[1]], def = tmp, tmp@name, verbose=FALSE)

# ff$functions$get_all_neighbors_by_gene(kid="eco:b0002", threshold= as.integer(500), orgs = c("ecs","ypk"))

\dontrun{
  x = ff@functions$get_paralogs_by_gene("eco:b0002", 1, 10)
}

  tp = get(".operation", environment(ff@functions$get_paralogs_by_gene))@returnValue


  # A different WSDL file.
  tmp = processWSDL(system.file("examples", "XMethodsFilesystemService.wsdl.xml", package = "SSOAP"))
}
\keyword{interface}
\keyword{connection}

==> SSOAP_0.4-1.tar.gz: SSOAP/man/processWSDL.Rd <==
\name{processWSDL}
\alias{processWSDL}
\title{Read and process a Web Service Description Language file}
\description{
  This reads and converts a WSDL file for a server
  into a collection of functions and methods.
}
\usage{
processWSDL(fileName = "KEGG.wsdl", handlers = WSDLParseHandlers(fileName))
}
\arguments{
  \item{fileName}{the name of the WSDL file or URI.}
  \item{handlers}{a list of handler functions that are passed to
    \code{\link[XML]{xmlTreeParse}} to perform transformations on the XML
      nodes as the are parsed and converted to R objects.
      The default handlers drop comments and take care of importing
      files that are referenced via <wsdl:import> nodes.}
}

\details{

}
\value{
   An object of class \code{\link{SOAPServerDescription}}.
}

\author{Duncan Temple Lang <duncan@wald.ucdavis.edu>}
\seealso{
  \code{UseDashInSOAPNames} is an R option that can be set by the
  user that is understood by this package to control
  whether to either leave SOAP method names as-is,
  or if \code{FALSE}, to remove \code{_} in the
  names and capitalize the first character in all but
  the first word of the name. In other words, if
  \code{UseDashInSOAPNames} is set to FALSE,
  the name \code{abc_def_ghi} is mapped to
  \code{abcDefGhi}.  By default,
  the value is unset and
  treated as \code{TRUE}, so dashes are preserved.
}

\examples{
  tmp = processWSDL(system.file("examples", "KEGG.wsdl", package = "SSOAP"))

   # The first set of operations, and the method "color_pathway_by_objects"
  o = tmp@operations[[1]][["color_pathway_by_objects"]]
  names(o@parameters)
  o@parameters[["fg_color_list"]]
  o@returnValue


  ff = genSOAPClientInterface(tmp@operations[[1]], def = tmp, tmp@name, verbose=FALSE)

# ff$functions$get_all_neighbors_by_gene(kid="eco:b0002", threshold= as.integer(500), orgs = c("ecs","ypk"))

\dontrun{
  x = ff@functions$get_paralogs_by_gene("eco:b0002", 1, 10)
}

  tp = get(".operation", environment(ff@functions$get_paralogs_by_gene))@returnValue


  # A different WSDL file.
  tmp = processWSDL(system.file("examples", "XMethodsFilesystemService.wsdl.xml", package = "SSOAP"))
}
\keyword{interface}
\keyword{connection}
